[Cmake-commits] CMake branch, next, updated. v3.1.0-2105-g48ff2e8

Stephen Kelly steveire at gmail.com
Sun Jan 18 08:39:11 EST 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  48ff2e8cee3b0f28f2e65b59092682daa3930c45 (commit)
       via  7650c1b181904927d484fa41c2e80a347639e23d (commit)
       via  f4ce62450e1952803947eeb8dbcb00ada9d2d3fe (commit)
      from  6961e240b4b856326ac91ecb37169c71277cd597 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=48ff2e8cee3b0f28f2e65b59092682daa3930c45
commit 48ff2e8cee3b0f28f2e65b59092682daa3930c45
Merge: 6961e24 7650c1b
Author:     Stephen Kelly <steveire at gmail.com>
AuthorDate: Sun Jan 18 08:39:10 2015 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Sun Jan 18 08:39:10 2015 -0500

    Merge topic 'GNU-4.4-compile-features' into next
    
    7650c1b1 Features: Use a more-common feature in cycle-test.
    f4ce6245 Features: Update comment in test to match the code.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7650c1b181904927d484fa41c2e80a347639e23d
commit 7650c1b181904927d484fa41c2e80a347639e23d
Author:     Stephen Kelly <steveire at gmail.com>
AuthorDate: Sun Jan 18 14:37:34 2015 +0100
Commit:     Stephen Kelly <steveire at gmail.com>
CommitDate: Sun Jan 18 14:37:34 2015 +0100

    Features: Use a more-common feature in cycle-test.
    
    We require that the $<$<COMPILE_FEATURES:cxx_feature>:empty2> generates
    a '1' when CXX11 is enabled.  GNU 4.4 does not support cxx_nullptr, but
    does support cxx_auto_type.

diff --git a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
index d2c95ec..684fb2b 100644
--- a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
+++ b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
@@ -9,7 +9,7 @@ target_link_libraries(empty1
   # When starting, $<COMPILE_FEATURES:cxx_nullptr> is '0', so 'freeze' the
   # CXX_STANDARD at 98 during computation.
   $<$<COMPILE_FEATURES:cxx_nullptr>:empty2>
-  # This would add cxx_constexpr, but that would require CXX_STANDARD = 11,
+  # This would add cxx_static_assert, but that would require CXX_STANDARD = 11,
   # which is not allowed after freeze.  Report an error.
   empty3
 )

-----------------------------------------------------------------------

Summary of changes:
 .../CompileFeatures/LinkImplementationFeatureCycle.cmake         |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)


hooks/post-receive
diff --git a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
index 684fb2b..09594bd 100644
--- a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
+++ b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
@@ -6,9 +6,9 @@ add_library(empty3 INTERFACE)
 target_compile_features(empty3 INTERFACE cxx_static_assert)
 
 target_link_libraries(empty1
   # When starting, $<COMPILE_FEATURES:cxx_nullptr> is '0', so 'freeze' the
   # CXX_STANDARD at 98 during computation.
-  $<$<COMPILE_FEATURES:cxx_nullptr>:empty2>
+  $<$<COMPILE_FEATURES:cxx_auto_type>:empty2>
   # This would add cxx_static_assert, but that would require CXX_STANDARD = 11,
   # which is not allowed after freeze.  Report an error.
   empty3
@@ -6,9 +6,9 @@ add_library(empty3 INTERFACE)
 
 target_link_libraries(empty1
-  # When starting, $<COMPILE_FEATURES:cxx_nullptr> is '0', so 'freeze' the
+  # When starting, $<COMPILE_FEATURES:cxx_auto_type> is '0', so 'freeze' the
   # CXX_STANDARD at 98 during computation.

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f4ce62450e1952803947eeb8dbcb00ada9d2d3fe
commit f4ce62450e1952803947eeb8dbcb00ada9d2d3fe
Author:     Stephen Kelly <steveire at gmail.com>
AuthorDate: Sun Jan 18 14:36:01 2015 +0100
Commit:     Stephen Kelly <steveire at gmail.com>
CommitDate: Sun Jan 18 14:36:25 2015 +0100

    Features: Update comment in test to match the code.
    
    After commit f13a2eb1 (Features: Adjust the RunCMake test to use
    more-common features., 2015-01-15).

-- 
CMake


More information about the Cmake-commits mailing list